==> graphql_compose_webform-1.0.x-dev.tar.gz: graphql_compose_webform/src/Plugin/GraphQL/DataProducer/WebformLoad.php <==
<?php

declare(strict_types=1);

namespace Drupal\graphql_compose_webform\Plugin\GraphQL\DataProducer;

use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\graphql\GraphQL\Execution\FieldContext;
use Drupal\graphql\Plugin\GraphQL\DataProducer\DataProducerPluginBase;
use Drupal\webform\WebformInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Load drupal webform.
 *
 * @DataProducer(
 *   id = "webform_load",
 *   name = @Translation("Webform loader"),
 *   description = @Translation("Load a webform."),
 *   produces = @ContextDefinition("any",
 *     label = @Translation("Webform instance"),
 *   ),
 *   consumes = {
 *     "id" = @ContextDefinition("string",
 *       label = @Translation("Webform plugin ID"),
 *     ),
 *   },
 * )
 */
class WebformLoad extends DataProducerPluginBase implements ContainerFactoryPluginInterface {

  /**
   * Constructs a WebformLoad object.
   *
   * @param array $configuration
   *   The plugin configuration.
   * @param string $plugin_id
   *   The plugin id.
   * @param mixed $plugin_definition
   *   The plugin definition.
   * @param \Drupal\Core\Block\EntityTypeManagerInterface $entityTypeManager
   *   Drupal Entity Type manager.
   */
  public function __construct(
    array $configuration,
    $plugin_id,
    $plugin_definition,
    protected EntityTypeManagerInterface $entityTypeManager,
  ) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('entity_type.manager'),
    );
  }

  /**
   * Resolve the layout definition.
   *
   * @param string $webform_id
   *   The block plugin ID.
   * @param \Drupal\graphql\GraphQL\Execution\FieldContext $context
   *   The cache context.
   *
   * @return \Drupal\webform\WebformInterface|null
   *   The block plugin instance.
   */
  public function resolve(string $webform_id, FieldContext $context): ?WebformInterface {

    /** @var \Drupal\webform\WebformInterface $webform_instance */
    $webform_instance = $this->entityTypeManager->getStorage('webform')
      ->load($webform_id);
    $context->addCacheableDependency($webform_instance);

    return $webform_instance;
  }

}

==> graphql_compose_webform-1.1.x-dev.tar.gz: graphql_compose_webform/src/Plugin/GraphQL/DataProducer/WebformLoad.php <==
<?php

declare(strict_types=1);

namespace Drupal\graphql_compose_webform\Plugin\GraphQL\DataProducer;

use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\graphql\GraphQL\Execution\FieldContext;
use Drupal\graphql\Plugin\GraphQL\DataProducer\DataProducerPluginBase;
use Drupal\webform\WebformInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Load drupal webform.
 *
 * @DataProducer(
 *   id = "webform_load",
 *   name = @Translation("Webform loader"),
 *   description = @Translation("Load a webform."),
 *   produces = @ContextDefinition("entity",
 *     label = @Translation("Webform instance"),
 *   ),
 *   consumes = {
 *     "id" = @ContextDefinition("string",
 *       label = @Translation("Webform plugin ID"),
 *     ),
 *   },
 * )
 */
class WebformLoad extends DataProducerPluginBase implements ContainerFactoryPluginInterface {

  /**
   * Constructs a WebformLoad object.
   *
   * @param array $configuration
   *   The plugin configuration.
   * @param string $plugin_id
   *   The plugin id.
   * @param mixed $plugin_definition
   *   The plugin definition.
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entityTypeManager
   *   Drupal Entity Type manager.
   */
  public function __construct(
    array $configuration,
    $plugin_id,
    $plugin_definition,
    protected EntityTypeManagerInterface $entityTypeManager,
  ) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('entity_type.manager'),
    );
  }

  /**
   * Resolve the layout definition.
   *
   * @param string $webform_id
   *   The block plugin ID.
   * @param \Drupal\graphql\GraphQL\Execution\FieldContext $context
   *   The cache context.
   *
   * @return \Drupal\webform\WebformInterface
   *   The block plugin instance.
   */
  public function resolve(string $webform_id, FieldContext $context): WebformInterface {

    /** @var \Drupal\webform\WebformInterface $webform_instance */
    $webform_instance = $this->entityTypeManager->getStorage('webform')
      ->load($webform_id);
    $context->addCacheableDependency($webform_instance);

    return $webform_instance;
  }

}
